==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Sitenizin adresi', # MODIF
	'form_pet_aucune_signature' => 'Bu koda karşılık hiç bir imza yok...', # MODIF
	'form_pet_confirmation' => 'Lütfen imzanızı onaylayınız :',
	'form_pet_deja_signe' => 'Bu metni zaten imzalamışsınız.',
	'form_pet_envoi_mail_confirmation' => 'Şu anda @email@ adresine bir doğrulama e-postası gönderildi. İmzanızı doğrulamak için bu iletide belirtilen web adresini ziyaret etmelisiniz.', # MODIF
	'form_pet_mail_confirmation' => 'Merhaba,

Bir dilekçe imzalamak istediniz :
@titre@.

Ve şu bilgileri girdiniz :
    İsim: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@


ÖNEMLİ ...
İmzanızı onaylamak için aşağıdaki adrese bağlanmanız yeterli
 (aksi halde isteğiniz
reddedilecektir) :

    @url@


Katılımınız için teşekkürler
',
	'form_pet_message_commentaire' => 'Bir ileti, bir yorum ?', # MODIF
	'form_pet_nom_site2' => 'Sitenizin ismi', # MODIF
	'form_pet_probleme_liens' => 'Lütfen iletinizi hipermetin bağlarını silerek tekrar giriniz',
	'form_pet_probleme_technique' => 'Teknik bir sorun var, imzalar geçici olarak iptal edildi.',
	'form_pet_signature_validee' => 'İmzanız onaylandı. Teşekkürler !',
	'form_pet_site_deja_enregistre' => 'Bu site zaten kayıtlı',
	'form_pet_url_invalide' => 'Belirttiğiniz Url geçerli değil.',
	'form_pet_votre_email' => 'E-posta adresiniz',
	'form_pet_votre_nom' => 'İsminiz veya takma isminiz', # MODIF
	'form_pet_votre_site' => 'Eğer bir siteniz varsa bunu aşağıda belirtebilirsiniz',

	// I
	'info_adresse_email' => 'E-POSTA ADRESİ :',
	'info_signature_supprimee' => 'İmza silinmiş',
	'info_signature_supprimee_erreur' => 'Hata : bu silme kodu hiçbir imzaya karşı düşmüyor', # MODIF
	'info_site_web' => 'WEB SiTESİ :',

	// L
	'lien_reponse_article' => 'Bu makaleye yanıt '
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'İmza kampanyasını aç',
	'bouton_radio_pas_petition' => 'Dilekçe yok',
	'bouton_radio_petition_activee' => 'Etkinleştirilmiş dilekçe',
	'bouton_radio_supprimer_petition' => 'Dilekçeyi sil',

	// F
	'form_pet_adresse_site' => 'Sitenizin adresi', # MODIF
	'form_pet_aucune_signature' => 'Bu koda karşılık hiç bir imza yok...', # MODIF
	'form_pet_confirmation' => 'Lütfen imzanızı onaylayınız :',
	'form_pet_deja_signe' => 'Bu metni zaten imzalamışsınız.',
	'form_pet_envoi_mail_confirmation' => 'Şu anda @email@ adresine bir doğrulama e-postası gönderildi. İmzanızı doğrulamak için bu iletide belirtilen web adresini ziyaret etmelisiniz.', # MODIF
	'form_pet_mail_confirmation' => 'Merhaba,

Bir dilekçe imzalamak istediniz :
@titre@.

Ve şu bilgileri girdiniz :
    İsim: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@


ÖNEMLİ ...
İmzanızı onaylamak için aşağıdaki adrese bağlanmanız yeterli
 (aksi halde isteğiniz
reddedilecektir) :

    @url@


Katılımınız için teşekkürler
',
	'form_pet_message_commentaire' => 'Bir ileti, bir yorum ?', # MODIF
	'form_pet_nom_site2' => 'Sitenizin ismi', # MODIF
	'form_pet_probleme_liens' => 'Lütfen iletinizi hipermetin bağlarını silerek tekrar giriniz',
	'form_pet_probleme_technique' => 'Teknik bir sorun var, imzalar geçici olarak iptal edildi.',
	'form_pet_signature_validee' => 'İmzanız onaylandı. Teşekkürler !',
	'form_pet_site_deja_enregistre' => 'Bu site zaten kayıtlı',
	'form_pet_url_invalide' => 'Belirttiğiniz Url geçerli değil.',
	'form_pet_votre_email' => 'E-posta adresiniz',
	'form_pet_votre_nom' => 'İsminiz veya takma isminiz', # MODIF
	'form_pet_votre_site' => 'Eğer bir siteniz varsa bunu aşağıda belirtebilirsiniz',

	// I
	'info_adresse_email' => 'E-POSTA ADRESİ :',
	'info_signature_supprimee' => 'İmza silinmiş',
	'info_signature_supprimee_erreur' => 'Hata : bu silme kodu hiçbir imzaya karşı düşmüyor', # MODIF
	'info_site_web' => 'WEB SiTESİ :',

	// L
	'lien_reponse_article' => 'Bu makaleye yanıt '
);

?>
